@@ -1,7 +1,7 @@
 /*=============================================================================
 *
 *   WCSLIB - an implementation of the FITS WCS proposal.
-*   Copyright (C) 1995-2001, Mark Calabretta
+*   Copyright (C) 1995-2002, Mark Calabretta
 *
 *   This library is free software; you can redistribute it and/or modify it
 *   under the terms of the GNU Library General Public License as published
@@ -160,7 +160,7 @@
 *   leak will result.
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
-*   $Id: lin.c,v 2.6 2001/11/15 03:24:48 mcalabre Exp $
+*   $Id: lin.c,v 2.8 2002/01/30 06:04:03 mcalabre Exp $
 *===========================================================================*/
 
 #include <math.h>
@@ -183,7 +183,7 @@ const char *linrev_errmsg[] = {
    "PC matrix is singular"};
 
 
-#ifdef __convexc__
+#if defined(__convexc__) || defined(__APPLE__)
 #include <stdlib.h>
 #else
 #include <malloc.h>
